Leet
====

`Leet code`_ encoder/decoder

.. _`Leet code`: https://zh.wikipedia.org/zh-hant/Leet

Usage
-----

Example:

.. code-block:: python

    >>> from leetehao import leet
    >>> leet.encode('hello world')
    '}{[-[_[_()  vv()[z[_|)'
    >>> leet.encode('}{[-[_[_()  vv()[z[_|)')
    'HELLO WORLD'
